@@ -1,6 +1,6 @@
 package Task::BeLike::SHARYANTO::Noted;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 1;
 # ABSTRACT: Some modules which I take note of because I can never remember their names
@@ -15,7 +15,7 @@ Task::BeLike::SHARYANTO::Noted - Some modules which I take note of because I can
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
@@ -24,19 +24,31 @@ because I can never seem to remember their names, usually because the name is
 not representative of what the module does, or the term is unusual, or both. Or
 it's just my failing memory.
 
-They are categorized by functionalities/topics.
+They are categorized by task.
 
 =head1 TASK CONTENTS
 
-=head2 Modules to prevent multiple instances of script running simultaneously
+=head2 Prevent multiple instances of script from running simultaneously
 
-Similar in functionality to L<Proc::PID::File>.
+Similar to L<Proc::PID::File>.
 
 =head3 L<Sys::RunAlone>
 
+=head2 Automatically download, install, load CPAN modules upon first use
+
+Similar to L<Module::AutoLoad>, L<Module::AutoINC>.
+
+=head3 L<lib::xi>
+
+=head2 Automatically load classes/modules upon first use
+
+Similar to L<Class::Autouse>.
+
+=head3 L<L>
+
 =head1 FAQ
 
-=head2 Why don't you just favorite the module in MetaCPAN?
+=head2 Why don't you just favorite the modules in MetaCPAN?
 
 I reserve that for modules which I like/use and would like to be installed on my
 Perl installations.
